@@ -155,7 +155,7 @@ C
   225 K=I
 C                                  SELECT A CENTRAL ELEMENT OF THE
 C                                  ARRAY AND SAVE IT IN LOCATION T
-      IJ = I + (DFLOAT (J-I) *R)
+      IJ = I + (DBLE (J-I) *R)
       T=X(IJ)
       TY= Y(IJ)
 C                                  IF FIRST ELEMENT OF ARRAY IS GREATER
